@@ -342,9 +342,7 @@ ttestPSClass <- R6::R6Class(
                 ggtheme + theme(plot.title = ggplot2::element_text(margin=ggplot2::margin(b = 5.5 * 1.2)),
                               plot.margin = ggplot2::margin(5.5, 5.5, 5.5, 5.5))
 
-            suppressWarnings(print(plot))
-
-            return(TRUE)
+            return(plot)
         },
         .qq=function(image, ggtheme, theme, ...) {
             if (is.null(image$state))
@@ -365,9 +363,7 @@ ttestPSClass <- R6::R6Class(
                 ylab("Standardized Residuals") +
                 ggtheme
 
-            print(plot)
-
-            return(TRUE)
+            return(plot)
         }
     )
 )
